@@ -15,6 +15,7 @@
 
 from __future__ import absolute_import
 
+import os
 import sys
 import traceback
 from pprint import pprint
@@ -25,6 +26,8 @@ from . import optcomplete
 from rackspace_monitoring.providers import get_driver
 from rackspace_monitoring.types import Provider
 
+from libcloud import _init_once
+
 from raxmon_cli.constants import GLOBAL_OPTIONS, ACTION_OPTIONS
 from raxmon_cli.constants import API_URL_ADDRESS
 from raxmon_cli.printers import print_list, print_error, print_success
@@ -95,6 +98,10 @@ def run_action(cmd_options, required_options, resource, action, callback):
               'pass them to the command using --username and --api-key option')
         sys.exit(1)
 
+    if options.debug:
+        os.environ['LIBCLOUD_DEBUG'] = '/dev/stderr'
+        _init_once()
+
     instance = get_instance(username, api_key, api_url)
 
     if not getattr(options, 'who', None):
